@@ -602,7 +602,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
                                   "max_render_depth "
                                   "simple_slavegrid_header "
                                   "paginator_template "
-                                  # "hide_top_toolbar "
+                                  "hide_top_toolbar "
                                   "hide_if_empty "
                                   "borderless_list_mode "
                                ))
@@ -615,6 +615,9 @@ class Renderer(JsRenderer, JsCacheRenderer):
             if wl is not None:
                 result.update(window_layout=wl._formpanel_name)
 
+        if v.active_fields:
+            result.update(active_fields=list(v.active_fields))
+
         card_layout = getattr(v, "card_layout", None)
         if card_layout is not None:
             result.update(card_layout=card_layout._formpanel_name)
