@@ -674,7 +674,7 @@ class UserSettings(View):
 
                 if settings.SITE.plugins.users.allow_online_registration:
                     require_verification = not u.is_verified()
-                    if require_verification:
+                    if require_verification and u.verification_code_sent_on is not None:
                         user_settings['require_verification'] = True
                         expiry_time = (u.verification_code_sent_on + datetime.timedelta(
                             minutes=settings.SITE.plugins.users.verification_code_expires
@@ -686,4 +686,7 @@ class UserSettings(View):
 
             return json_response(user_settings)
 
+        # f = open('non-existent-file.txt', 'r')
+
         return with_user_profile((su or u).user_type, getit)
+        # return http.HttpResponse(status=500)
